# BreezyHR Connector

## About BreezyHR :

Workable is a software designed to assist teams in finding the right candidates, evaluating applicants, and making a hire more quickly. 

It helps streamline the recruitment process and identify the best fit for a position.

## Connector features :

- **Push profiles :**  Retrieves profiles from HrFlow Souce export API and sends them to Workable ATS
- **Pull Jobs :** Retrieves jobs from Workable vacancies export API  and sends them to a [HrFlow.ai](http://HrFlow.ai) Board

**Useful links:**

📄Visit [Workable](https://www.workable.com/) to learn more.

💻 [Connector code](https://github.com/Sprenger07/hrflow-connectors/tree/feature/update-connector-workable/src/hrflow_connectors/connectors/workable) on our Github.

**Useful links:**

📄Visit [Workable](https://www.workable.com/) to learn more.

💻 [Connector code](https://github.com/Sprenger07/hrflow-connectors/tree/feature/update-connector-workable/src/hrflow_connectors/connectors/workable) on our Github.

**Screenshots :**

- **Push profiles :**

![image](https://user-images.githubusercontent.com/55802491/210258854-6eb81fb4-6844-4e36-86c0-63dd50baa218.png)

    
- **Pull Jobs :**

![image](https://user-images.githubusercontent.com/55802491/210258882-e9e0abda-62a5-4267-89f0-61460c10abe1.png)